netapp_ontap.models.group_policy_object_security_setting API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.group_policy_object_security_setting`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class GroupPolicyObjectSecuritySettingSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the GroupPolicyObjectSecuritySetting object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `event_audit_settings: GroupPolicyObjectEventAudit GET POST PATCH`

    The event_audit_settings field of the group_policy_object_security_setting.

  `event_log_settings: GroupPolicyObjectEventLog GET POST PATCH`

    The event_log_settings field of the group_policy_object_security_setting.

  `files_or_folders: List[str] GET POST PATCH`

    Files/Directories for file security.

    Example: ["/vol1/home","/vol1/dir1"]

  `kerberos: GroupPolicyObjectKerberos GET POST PATCH`

    The kerberos field of the group_policy_object_security_setting.

  `privilege_rights: GroupPolicyObjectPrivilegeRight GET POST PATCH`

    The privilege_rights field of the group_policy_object_security_setting.

  `registry_values: GroupPolicyObjectRegistryValue GET POST PATCH`

    The registry_values field of the group_policy_object_security_setting.

  `restrict_anonymous: GroupPolicyObjectRestrictAnonymous GET POST PATCH`

    The restrict_anonymous field of the group_policy_object_security_setting.

  `restricted_groups: List[str] GET POST PATCH`

    The restricted_groups field of the group_policy_object_security_setting.